pub struct TestEnvBuilder<R> { /* private fields */ }Implementations
Sourceimpl<R> TestEnvBuilder<R>
impl<R> TestEnvBuilder<R>
pub fn new() -> Self
Sourcepub fn add_package(self, pkg: Package) -> Self
pub fn add_package(self, pkg: Package) -> Self
Add a package to the repository generated by this TestEnvBuilder. The package will also be listed in the generated update package so that it will be downloaded as part of the OTA.
pub fn blobfs(self, client: ClientEnd<DirectoryMarker>) -> Self
Sourcepub fn repo_config(self, repo: RepositoryConfigs) -> Self
pub fn repo_config(self, repo: RepositoryConfigs) -> Self
Provide a TUF repository configuration to the package resolver. This will override the repository that the builder would otherwise generate.
pub fn system_image_hash(self, hash: Hash) -> Self
Sourcepub fn omaha_state(self, state: OmahaState) -> Self
pub fn omaha_state(self, state: OmahaState) -> Self
Enable/disable Omaha. OmahaState::Auto will automatically set up an Omaha server and tell the updater to use it.
Sourcepub fn paver<F>(self, func: F) -> Self
pub fn paver<F>(self, func: F) -> Self
Mutate the MockPaverServiecBuilder used by this TestEnvBuilder.
pub fn test_executor(self, executor: Box<dyn TestExecutor<R>>) -> Self
Sourcepub fn fuchsia_image(self, zbi: Vec<u8>, vbmeta: Option<Vec<u8>>) -> Self
pub fn fuchsia_image(self, zbi: Vec<u8>, vbmeta: Option<Vec<u8>>) -> Self
The zbi and optional vbmeta images to write.
Sourcepub fn recovery_image(self, zbi: Vec<u8>, vbmeta: Option<Vec<u8>>) -> Self
pub fn recovery_image(self, zbi: Vec<u8>, vbmeta: Option<Vec<u8>>) -> Self
The zbi and optional vbmeta images to write to the recovery partition.
Sourcepub fn firmware_image(self, type_: String, content: Vec<u8>) -> Self
pub fn firmware_image(self, type_: String, content: Vec<u8>) -> Self
A firmware image to write.